@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -57,7 +57,7 @@ __all__ = ("HoneycodeClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -78,7 +78,7 @@ class Exceptions:
 
 class HoneycodeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html)
     """
 
@@ -95,25 +95,30 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowsToCreate: List["CreateRowDataTypeDef"],
+        rowsToCreate: Sequence["CreateRowDataTypeDef"],
         clientRequestToken: str = None
     ) -> BatchCreateTableRowsResultTypeDef:
         """
         The BatchCreateTableRows API allows you to create one or more rows at the end of
         a table in a workbook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_create_table_rows)
         """
 
     def batch_delete_table_rows(
-        self, *, workbookId: str, tableId: str, rowIds: List[str], clientRequestToken: str = None
+        self,
+        *,
+        workbookId: str,
+        tableId: str,
+        rowIds: Sequence[str],
+        clientRequestToken: str = None
     ) -> BatchDeleteTableRowsResultTypeDef:
         """
         The BatchDeleteTableRows API allows you to delete one or more rows from a table
         in a workbook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_delete_table_rows)
         """
 
@@ -122,14 +127,14 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowsToUpdate: List["UpdateRowDataTypeDef"],
+        rowsToUpdate: Sequence["UpdateRowDataTypeDef"],
         clientRequestToken: str = None
     ) -> BatchUpdateTableRowsResultTypeDef:
         """
         The BatchUpdateTableRows API allows you to update one or more rows in a table in
         a workbook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_update_table_rows)
         """
 
@@ -138,13 +143,13 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowsToUpsert: List["UpsertRowDataTypeDef"],
+        rowsToUpsert: Sequence["UpsertRowDataTypeDef"],
         clientRequestToken: str = None
     ) -> BatchUpsertTableRowsResultTypeDef:
         """
         The BatchUpsertTableRows API allows you to upsert one or more rows in a table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_upsert_table_rows)
         """
 
@@ -152,7 +157,7 @@ class HoneycodeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#can_paginate)
         """
 
@@ -163,21 +168,21 @@ class HoneycodeClient(BaseClient):
         The DescribeTableDataImportJob API allows you to retrieve the status and details
         of a table data import job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#describe_table_data_import_job)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#generate_presigned_url)
         """
 
@@ -187,14 +192,14 @@ class HoneycodeClient(BaseClient):
         workbookId: str,
         appId: str,
         screenId: str,
-        variables: Dict[str, "VariableValueTypeDef"] = None,
+        variables: Mapping[str, "VariableValueTypeDef"] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> GetScreenDataResultTypeDef:
         """
         The GetScreenData API allows retrieval of data from a screen in a Honeycode app.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_screen_data)
         """
 
@@ -205,7 +210,7 @@ class HoneycodeClient(BaseClient):
         appId: str,
         screenId: str,
         screenAutomationId: str,
-        variables: Dict[str, "VariableValueTypeDef"] = None,
+        variables: Mapping[str, "VariableValueTypeDef"] = None,
         rowId: str = None,
         clientRequestToken: str = None
     ) -> InvokeScreenAutomationResultTypeDef:
@@ -213,7 +218,7 @@ class HoneycodeClient(BaseClient):
         The InvokeScreenAutomation API allows invoking an action defined in a screen in
         a Honeycode app.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#invoke_screen_automation)
         """
 
@@ -224,7 +229,7 @@ class HoneycodeClient(BaseClient):
         The ListTableColumns API allows you to retrieve a list of all the columns in a
         table in a workbook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_table_columns)
         """
 
@@ -233,7 +238,7 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowIds: List[str] = None,
+        rowIds: Sequence[str] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> ListTableRowsResultTypeDef:
@@ -241,7 +246,7 @@ class HoneycodeClient(BaseClient):
         The ListTableRows API allows you to retrieve a list of all the rows in a table
         in a workbook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_table_rows)
         """
 
@@ -252,7 +257,7 @@ class HoneycodeClient(BaseClient):
         The ListTables API allows you to retrieve a list of all the tables in a
         workbook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.list_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_tables)
         """
 
@@ -269,7 +274,7 @@ class HoneycodeClient(BaseClient):
         The QueryTableRows API allows you to use a filter formula to query for specific
         rows in a table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#query_table_rows)
         """
 
@@ -286,7 +291,7 @@ class HoneycodeClient(BaseClient):
         """
         The StartTableDataImportJob API allows you to start an import job on a table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#start_table_data_import_job)
         """
 
@@ -295,27 +300,27 @@ class HoneycodeClient(BaseClient):
         self, operation_name: Literal["list_table_columns"]
     ) -> ListTableColumnsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTableColumns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablecolumnspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_table_rows"]) -> ListTableRowsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTableRows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablerowspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.ListTables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#listtablespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_table_rows"]) -> QueryTableRowsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/honeycode.html#Honeycode.Paginator.QueryTableRows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/paginators.html#querytablerowspaginator)
         """
