@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     FormatType,
@@ -90,7 +90,7 @@ _RequiredBatchCreateTableRowsRequestRequestTypeDef = TypedDict(
     {
         "workbookId": str,
         "tableId": str,
-        "rowsToCreate": List["CreateRowDataTypeDef"],
+        "rowsToCreate": Sequence["CreateRowDataTypeDef"],
     },
 )
 _OptionalBatchCreateTableRowsRequestRequestTypeDef = TypedDict(
@@ -124,7 +124,7 @@ _RequiredBatchDeleteTableRowsRequestRequestTypeDef = TypedDict(
     {
         "workbookId": str,
         "tableId": str,
-        "rowIds": List[str],
+        "rowIds": Sequence[str],
     },
 )
 _OptionalBatchDeleteTableRowsRequestRequestTypeDef = TypedDict(
@@ -157,7 +157,7 @@ _RequiredBatchUpdateTableRowsRequestRequestTypeDef = TypedDict(
     {
         "workbookId": str,
         "tableId": str,
-        "rowsToUpdate": List["UpdateRowDataTypeDef"],
+        "rowsToUpdate": Sequence["UpdateRowDataTypeDef"],
     },
 )
 _OptionalBatchUpdateTableRowsRequestRequestTypeDef = TypedDict(
@@ -190,7 +190,7 @@ _RequiredBatchUpsertTableRowsRequestRequestTypeDef = TypedDict(
     {
         "workbookId": str,
         "tableId": str,
-        "rowsToUpsert": List["UpsertRowDataTypeDef"],
+        "rowsToUpsert": Sequence["UpsertRowDataTypeDef"],
     },
 )
 _OptionalBatchUpsertTableRowsRequestRequestTypeDef = TypedDict(
@@ -250,7 +250,7 @@ CreateRowDataTypeDef = TypedDict(
     "CreateRowDataTypeDef",
     {
         "batchItemId": str,
-        "cellsToCreate": Dict[str, "CellInputTypeDef"],
+        "cellsToCreate": Mapping[str, "CellInputTypeDef"],
     },
 )
 
@@ -352,7 +352,7 @@ _RequiredGetScreenDataRequestRequestTypeDef = TypedDict(
 _OptionalGetScreenDataRequestRequestTypeDef = TypedDict(
     "_OptionalGetScreenDataRequestRequestTypeDef",
     {
-        "variables": Dict[str, "VariableValueTypeDef"],
+        "variables": Mapping[str, "VariableValueTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -421,7 +421,7 @@ _RequiredInvokeScreenAutomationRequestRequestTypeDef = TypedDict(
 _OptionalInvokeScreenAutomationRequestRequestTypeDef = TypedDict(
     "_OptionalInvokeScreenAutomationRequestRequestTypeDef",
     {
-        "variables": Dict[str, "VariableValueTypeDef"],
+        "variables": Mapping[str, "VariableValueTypeDef"],
         "rowId": str,
         "clientRequestToken": str,
     },
@@ -486,7 +486,7 @@ _RequiredListTableRowsRequestRequestTypeDef = TypedDict(
 _OptionalListTableRowsRequestRequestTypeDef = TypedDict(
     "_OptionalListTableRowsRequestRequestTypeDef",
     {
-        "rowIds": List[str],
+        "rowIds": Sequence[str],
         "maxResults": int,
         "nextToken": str,
     },
@@ -697,7 +697,7 @@ UpdateRowDataTypeDef = TypedDict(
     "UpdateRowDataTypeDef",
     {
         "rowId": str,
-        "cellsToUpdate": Dict[str, "CellInputTypeDef"],
+        "cellsToUpdate": Mapping[str, "CellInputTypeDef"],
     },
 )
 
@@ -706,7 +706,7 @@ UpsertRowDataTypeDef = TypedDict(
     {
         "batchItemId": str,
         "filter": "FilterTypeDef",
-        "cellsToUpdate": Dict[str, "CellInputTypeDef"],
+        "cellsToUpdate": Mapping[str, "CellInputTypeDef"],
     },
 )
 
